@@ -7,7 +7,8 @@ from method.resources.Verification import VerificationResource
 
 AccountTypesLiterals = Literal[
     'ach',
-    'liability'
+    'liability',
+    'clearing'
 ]
 
 
@@ -23,6 +24,12 @@ AccountCapabilitiesLiterals = Literal[
 ]
 
 
+AccountStatusesLiterals = Literal[
+    'active',
+    'disabled'
+]
+
+
 class AccountACH(TypedDict):
     routing: int
     number: int
@@ -34,6 +41,11 @@ class AccountLiability(TypedDict):
     mask: str
 
 
+class AccountClearing(TypedDict):
+    routing: int
+    number: int
+
+
 class AccountLiabilityCreateOpts(TypedDict):
     mch_id: str
     account_number: str
@@ -42,9 +54,11 @@ class AccountLiabilityCreateOpts(TypedDict):
 class Account(TypedDict):
     id: str
     holder_id: str
+    status: AccountStatusesLiterals
     type: AccountTypesLiterals
     ach: Optional[AccountACH]
     liability: Optional[AccountLiability]
+    clearing: Optional[AccountClearing]
     capabilities: List[AccountCapabilitiesLiterals]
     created_at: str
     updated_at: str
